@@ -56,14 +56,14 @@ Main features
    computation to disk and rerun it only if necessary::
 
       >>> from joblib import Memory
-      >>> cachedir = 'your_cache_dir_goes_here'
-      >>> mem = Memory(cachedir)
+      >>> location = 'your_cache_dir_goes_here'
+      >>> mem = Memory(location, verbose=1)
       >>> import numpy as np
       >>> a = np.vander(np.arange(3)).astype(float)
       >>> square = mem.cache(np.square)
       >>> b = square(a)                                   # doctest: +ELLIPSIS
       ______________________________________________________________________...
-      [Memory] Calling square...
+      [Memory] Calling ...square...
       square(array([[0., 0., 1.],
              [1., 1., 1.],
              [4., 2., 1.]]))
@@ -86,7 +86,7 @@ Main features
    *joblib.dump* & *joblib.load* ).
 
 ..
-    >>> import shutil ; shutil.rmtree(cachedir)
+    >>> import shutil ; shutil.rmtree(location)
 
 """
 
@@ -106,41 +106,56 @@ Main features
 # Dev branch marker is: 'X.Y.dev' or 'X.Y.devN' where N is an integer.
 # 'X.Y.dev0' is the canonical version of 'X.Y.dev'
 #
-__version__ = '1.4.2'
+__version__ = "1.5.3"
 
 
 import os
 
-from .memory import Memory
-from .memory import MemorizedResult
-from .memory import register_store_backend
-from .memory import expires_after
-
-from .logger import PrintTime
-from .logger import Logger
-
-from .hashing import hash
-
-from .numpy_pickle import dump
-from .numpy_pickle import load
-
-from .compressor import register_compressor
-
-from .parallel import Parallel
-from .parallel import delayed
-from .parallel import cpu_count
-from .parallel import register_parallel_backend
-from .parallel import parallel_backend
-from .parallel import parallel_config
-from .parallel import effective_n_jobs
 from ._cloudpickle_wrapper import wrap_non_picklable_objects
+from ._parallel_backends import ParallelBackendBase
+from ._store_backends import StoreBackendBase
+from .compressor import register_compressor
+from .hashing import hash
+from .logger import Logger, PrintTime
+from .memory import MemorizedResult, Memory, expires_after, register_store_backend
+from .numpy_pickle import dump, load
+from .parallel import (
+    Parallel,
+    cpu_count,
+    delayed,
+    effective_n_jobs,
+    parallel_backend,
+    parallel_config,
+    register_parallel_backend,
+)
 
-
-__all__ = ['Memory', 'MemorizedResult', 'PrintTime', 'Logger', 'hash', 'dump',
-           'load', 'Parallel', 'delayed', 'cpu_count', 'effective_n_jobs',
-           'register_parallel_backend', 'parallel_backend', 'expires_after',
-           'register_store_backend', 'register_compressor',
-           'wrap_non_picklable_objects', 'parallel_config']
+__all__ = [
+    # On-disk result caching
+    "Memory",
+    "MemorizedResult",
+    "expires_after",
+    # Parallel code execution
+    "Parallel",
+    "delayed",
+    "cpu_count",
+    "effective_n_jobs",
+    "wrap_non_picklable_objects",
+    # Context to change the backend globally
+    "parallel_config",
+    "parallel_backend",
+    # Helpers to define and register store/parallel backends
+    "ParallelBackendBase",
+    "StoreBackendBase",
+    "register_compressor",
+    "register_parallel_backend",
+    "register_store_backend",
+    # Helpers kept for backward compatibility
+    "PrintTime",
+    "Logger",
+    "hash",
+    "dump",
+    "load",
+]
 
 
 # Workaround issue discovered in intel-openmp 2019.5:
